@@ -107,8 +107,9 @@ resolveHeight <- function(x, inViewer = TRUE, default = 40) {
 getWidgetId <- function(widget) {
   if (inherits(widget, "htmlwidget"))
     widget$elementId
-  else
-    stop("object is not an html widget")
+  else {
+    NULL
+  }
 }
 
 # Get information from previous objects being piped into 
@@ -143,9 +144,15 @@ processUpstream <- function(upstream, elementId = NULL, playerId = NULL) {
   if (inherits(upstream, "combineWidgets")) 
     upstream <- upstream$widgets
 
+  if (inherits(upstream, "knit_image_paths") && length(upstream))
+    upstream <- img(src = image_uri(upstream[1]))
+  
   if (inherits(upstream, c("shiny.tag", "htmlwidget")))
     upstream <- tagList(upstream)
-        
+       
+  if (is.character(upstream) && !is.na(upstream))
+    return(list(prevRglWidget = upstream))
+  
   if (is.list(upstream)) {
     # Objects upstream of the current one may need to know about an rgl widget,
     # or this object may need to know about an upstream rgl widget.  Stop when
@@ -200,6 +207,9 @@ asRow <- function(..., last = NA, height = NULL, colsize = 1) {
     orig <- do.call(combineWidgets, c(args, list(ncol = 1, rowsize = getHeights(args))))
   }
   origlen <- length(orig$widgets)
+  for (i in seq_len(origlen))
+    if (inherits(orig$widgets[[i]], "knit_image_paths"))
+      orig$widgets[[i]] <- img(src = image_uri(orig$widgets[[i]]))
   if (is.na(last))
     last <- origlen
   else if (last > origlen)
@@ -225,24 +235,48 @@ asRow <- function(..., last = NA, height = NULL, colsize = 1) {
 newElementId <- function(prefix)
   paste0(prefix, p_sample(100000, 1))
 
+knitrNeedsSnapshot <- function(options = knitr::opts_current$get()) {
+  if (!is.null(options$snapshot))
+    options$snapshot
+  else {
+    pandocTo <- opts_knit$get("rmarkdown.pandoc.to")
+    if (!length(pandocTo)) pandocTo <- ""
+    pandocTo %in% c("latex", "gsm")
+  }
+}
+
 rglwidget <- local({
   reuseDF <- NULL
 
   function(x = scene3d(minimal), width = figWidth(), height = figHeight(),
-           controllers = NULL, snapshot = !webgl,
+           controllers = NULL, 
            elementId = NULL,
            reuse = !interactive(),
            webGLoptions = list(preserveDrawingBuffer = TRUE), 
   	       shared = NULL, 
            minimal = TRUE, 
-           webgl = !latex, latex, 
+           webgl,
+           snapshot,
            shinyBrush = NULL, ...) {
-  if (missing(latex))
-    latex <- isTRUE(getOption("knitr.in.progress")) &&
-             identical(opts_knit$get("rmarkdown.pandoc.to"),
-                       "latex")
-  if (!webgl && is.logical(snapshot) && !snapshot)
-    stop("Must specify either 'snapshot' or 'webgl' or both")
+    
+  if (missing(snapshot)) {
+    if (missing(webgl)) {
+      if (isTRUE(getOption("knitr.in.progress")))
+        snapshot <- knitrNeedsSnapshot()
+      else
+        snapshot <- FALSE
+    } else 
+      snapshot <- !webgl
+  } else {
+    if (!is.logical(snapshot)) {
+      stop("snapshot must be TRUE or FALSE")
+    }
+  }
+  if (missing(webgl)) webgl <- !snapshot
+      
+  if (webgl == snapshot || is.na(webgl) || is.na(snapshot))
+    stop("Must specify either 'snapshot' or 'webgl' but not both")
+  
   origScene <- x
   force(shared) # It might plot something...
   	
@@ -268,7 +302,7 @@ rglwidget <- local({
   if (!inherits(x, "rglscene"))
     stop("First argument should be an rgl scene.")
   
-  if (!is.list(shared))
+  if (!is.null(shared) && !is.list(shared))
     shared <- list(shared)
   dependencies <- list(rglDependency, CanvasMatrixDependency)
   if (length(shared)) {
@@ -298,37 +332,44 @@ rglwidget <- local({
     width <- CSStoPixels(width)
   if (!is.null(height))
     height <- CSStoPixels(height)
-  x <- convertScene(x, width, height, snapshot = snapshot,
+  x <- convertScene(x, width, height,
                    elementId = elementId, reuse = reuseDF,
-                   webgl = webgl, latex = latex)
-  if (!webgl)
-    return(x)
-  
+                   webgl = webgl, snapshot = snapshot)
+
   if (!is.na(reuse))
     reuseDF <<- attr(x, "reuse")
   
   upstream <- processUpstream(controllers, elementId = elementId)
-  x$players <- upstream$players
-
-  x$webGLoptions <- webGLoptions
-
-  # create widget
-  attr(x, "TOJSON_ARGS") <- list(na = "string")
-  result <- structure(htmlwidgets::createWidget(
-    name = 'rglWebGL',
-    x = x,
-    width = width,
-    height = height,
-    package = 'rgl',
-    elementId = elementId,
-    dependencies = dependencies,
-    ...
-  ), rglReuse = attr(x, "reuse"), origScene = origScene)
   
+  if (webgl) {
+    x$players <- upstream$players
+
+    x$webGLoptions <- webGLoptions
+
+    # create widget
+    attr(x, "TOJSON_ARGS") <- list(na = "string")
+    result <- structure(htmlwidgets::createWidget(
+      name = 'rglWebGL',
+      x = x,
+      width = width,
+      height = height,
+      package = 'rgl',
+      elementId = elementId,
+      dependencies = dependencies,
+      ...
+    ), rglReuse = attr(x, "reuse"), origScene = origScene)
+    
+  } else {
+    if (is.list(upstream$objects)) {
+      result <- img(src = image_uri(x), width = width, height = height)
+    } else
+      result <- x
+  }
+    
   if (is.list(upstream$objects)) {
     do.call(combineWidgets, c(upstream$objects, 
                               list(result, 
-                                   rowsize = c(upstream$rowsizes, x$height), 
+                                   rowsize = c(upstream$rowsizes, height), 
                                    ncol = 1)))
   } else
     result
@@ -357,9 +398,22 @@ shinySetPar3d <- function(..., session,
     stop("function requires shiny")
   args <- list(...)
   argnames <- names(args)
+  if (length(args) == 1 && is.null(argnames)) {
+    args <- args[[1]]
+  }
+  # We might have been passed modified shinyGetPar3d output;
+  # clean it up.
+  args[["subscene"]] <- NULL
+  args[["tag"]] <- NULL
+  argnames <- names(args)
+  
+  if (is.null(argnames) || any(argnames == ""))
+    stop("Parameters must all be named")
+  
   badargs <- argnames[!(argnames %in% .Par3d) | argnames %in% .Par3d.readonly]
   if (length(badargs))
     stop("Invalid parameter(s): ", badargs)
+  
   for (arg in argnames) {
     session$sendCustomMessage("shinySetPar3d", 
                               list(subscene = subscene,
