@@ -80,7 +80,23 @@
   }
   
   .rglEnv$subsceneList <- NULL
-	 
+
+  # Workaround for incompatibility with quartz device
+  # By default only run this if we'll be using the X11 display on macOS
+  # and we're not on R.app.  options("rgl.startQuartz") can 
+  # override this.
+  # Then we need to start quartz() before starting rgl.
+  # See https://github.com/dmurdoch/rgl/issues/27
+  if (getOption("rgl.startQuartz", 
+         !onlyNULL && 
+         unixos == "Darwin" && 
+         .Platform$GUI != "AQUA") &&
+         interactive() && 
+         exists("quartz", getNamespace("grDevices"))) {
+    grDevices::quartz()
+    dev.off()
+  }
+  
   ret <- rgl.init(initValue, onlyNULL)
   
   if (!ret) {
