@@ -1,8 +1,7 @@
 # RGL-demo: subdivision surfaces
 # author: Daniel Adler
 
-rgl.demo.subdivision <- function()
-{
+rgl.demo.subdivision <- function() {
   # setup environment
   clear3d("all")
   view3d()
@@ -12,8 +11,7 @@ rgl.demo.subdivision <- function()
   # generate basic mesh
   obj <- oh3d()
 
-  part <- function( level, tx, ... )
-  {
+  part <- function( level, tx, ... ) {
     shade3d( translate3d( obj, tx, 0, 0 )
     , color="gray30", front="lines",alpha=0.5,back="lines", override=TRUE
     )
@@ -21,8 +19,6 @@ rgl.demo.subdivision <- function()
     , override=TRUE, ... )
   }
   
-  common <- c(alpha=0.5)
-  
   part(0, -5.50, color="blue"   )
   part(1, -1.75, color="yellow" )
   part(2,  1.75, color="red"    )
@@ -32,4 +28,3 @@ rgl.demo.subdivision <- function()
 
 open3d()
 rgl.demo.subdivision()
-
