@@ -1,4 +1,8 @@
 ## ----setup, include=FALSE-----------------------------------------------------
+if (!requireNamespace("rmarkdown") || !rmarkdown::pandoc_available("1.14")) {
+  warning(call. = FALSE, "These vignettes assume rmarkdown and pandoc version 1.14.  These were not found. Older versions will not work.")
+  knitr::knit_exit()
+}
 knitr::opts_chunk$set(echo = TRUE)
 library(rgl)
 options(rgl.useNULL = TRUE)
